function []=kette_anim(t,p,m)
% []=kette_anim(t,p,m)
%
% Animation der Kugelkette 
%
% input
%   t:       Zeitpositionen
%            Vektor der Dimension (1 x n)
%   p :      Aktuelle Position der Kugeln
%            Vektor der Dimension (k x n)
%            k=Anzahl der Kugeln
%            n=Anzahl der Zeitschritte
%            Der Eintrag p(:,i) entspricht den Positionen der Kugeln zum
%            Zeitpunkt t(i).
%   m :      Masse der Kugeln (optional)
%            Wenn angegeben werden die Kugeln entsprechend ihrer Masse
%            gezeichnet. Wenn nicht angegeben sind alle Kugeln gleich
%            gross.


% Anzahl Kugeln
k=size(p,1);

% Groesse der Kugeln
if nargin == 3
    % Masse gegeben
    d=max(m)-min(m);
    if d~=0;
        g=100/(max(m)-min(m))*(m-min(m))+100;
    else
        g=100*ones(k,1);
    end
else
    g=100*ones(k,1);
end

% Feder
w=linspace(0,20*pi,200);

% Schnelle Zeichenart waehlen.
figure;
set(gca,'DrawMode','Fast');
hold on

h_pos=zeros(k,1);
h_feder=zeros(k-1,1);

% Ausgangsposition zeichnen
for i=1:k-1
    h_pos(i)=plot(p(i,1),0, 'LineStyle','none', 'Marker','.', 'MarkerSize',g(i));
    z=linspace(p(i,1),p(i+1,1),200);
    h_feder(i)=plot(z,0.02*sin(w));
end
h_pos(k)=plot(p(k,1),0, 'LineStyle','none', 'Marker','.', 'MarkerSize',g(k));

% Anzahl Zeitschritte
n=size(p,2);

% Achsen anpassen
axis([min(p(:,1))-2  max(p(:,1))+2 -1 1]);

% Position updaten
for l=2:n
    for i=1:k-1
        set(h_pos(i),'XData',p(i,l));
        z=linspace(p(i,l),p(i+1,l),200);
        set(h_feder(i),'XData',z);
    end
    set(h_pos(k),'XData',p(k,l));
    % Pause abhaengig von Zeitschritt, aber nicht weniger als 10^-2, da
    % sonst Grafik-Probleme zu erwarten sind.
    pause(max(t(l)-t(l-1),10^(-2)));
end